@@ -1,11 +1,13 @@
 from .Rrandom import Random
 from .Rmath import Math
+from .Rmath import Object, Point
 from .Rrequests import Request
 from .Rsugaku import Sugaku
 from .Rusty import Rusty
 from .Rusty import Webhook
-from .Rusty import console
+from .Rusty import Rconsole
 from .Rusty import Rplus
 from .Rcolor import Back
+from .Rkon import Kon
 
-__all__ = ['Random', 'init', 'Math', 'Request', 'Sugaku', 'Rusty', 'Webhook', 'Rplus', 'Back']
+__all__ = ['Kon','Object','Point','Random', 'init', 'Math', 'Request', 'Sugaku', 'Rusty', 'Webhook', 'Rplus', 'Back', 'Rconsole']
